@@ -1,10 +1,11 @@
 package Fey::Hash::ColumnsKey;
+BEGIN {
+  $Fey::Hash::ColumnsKey::VERSION = '0.33';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '0.32';
-
 sub new {
     my $class = shift;
 
@@ -32,12 +33,20 @@ sub store {
 
 1;
 
-__END__
+# ABSTRACT: A hash where the keys are sets of Fey::Column objects
+
+
+
+=pod
 
 =head1 NAME
 
 Fey::Hash::ColumnsKey - A hash where the keys are sets of Fey::Column objects
 
+=head1 VERSION
+
+version 0.33
+
 =head1 SYNOPSIS
 
   my $hash = Fey::Hash::ColumnsKey->new();
@@ -52,18 +61,17 @@ never need to use it directly.
 
 =head1 AUTHOR
 
-Dave Rolsky, <autarch@urth.org>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-See L<Fey::ORM> for details.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. The full text of the license
-can be found in the LICENSE file included with this module.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
