@@ -1,11 +1,12 @@
 package Fey::Meta::Attribute::FromInflator;
+BEGIN {
+  $Fey::Meta::Attribute::FromInflator::VERSION = '0.33';
+}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.32';
-
 use Moose;
 
 extends 'Moose::Meta::Attribute';
@@ -32,11 +33,19 @@ __PACKAGE__->meta()->make_immutable( inline_constructor => 0 );
 
 1;
 
-__END__
+# ABSTRACT: An attribute metaclass for attributes with an inflator
+
+
+
+=pod
 
 =head1 NAME
 
-Fey::Meta::Attribute::FromInflator - an attribute metaclass for attributes with an inflator
+Fey::Meta::Attribute::FromInflator - An attribute metaclass for attributes with an inflator
+
+=head1 VERSION
+
+version 0.33
 
 =head1 SYNOPSIS
 
@@ -71,18 +80,17 @@ Returns the L<Fey::Column> object associated with the raw attribute.
 
 =head1 AUTHOR
 
-Dave Rolsky, <autarch@urth.org>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-See L<Fey::ORM> for details.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. The full text of the license
-can be found in the LICENSE file included with this module.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
