@@ -1,10 +1,11 @@
 package Fey::Meta::Attribute::FromSelect;
+BEGIN {
+  $Fey::Meta::Attribute::FromSelect::VERSION = '0.33';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '0.32';
-
 use namespace::autoclean;
 use Moose;
 
@@ -48,15 +49,26 @@ __PACKAGE__->meta()->make_immutable( inline_constructor => 0 );
 
 package    # hide from PAUSE
     Moose::Meta::Attribute::Custom::FromSelect;
+BEGIN {
+  $Moose::Meta::Attribute::Custom::FromSelect::VERSION = '0.33';
+}
 sub register_implementation {'Fey::Meta::Attribute::FromSelect'}
 
 1;
 
-__END__
+# ABSTRACT: An attribute metaclass for SELECT-based attributes
+
+
+
+=pod
 
 =head1 NAME
 
-Fey::Meta::Attribute::FromSelect - an attribute metaclass for SELECT-based attributes
+Fey::Meta::Attribute::FromSelect - An attribute metaclass for SELECT-based attributes
+
+=head1 VERSION
+
+version 0.33
 
 =head1 SYNOPSIS
 
@@ -123,18 +135,17 @@ single column.
 
 =head1 AUTHOR
 
-Dave Rolsky, <autarch@urth.org>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-See L<Fey::ORM> for details.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. The full text of the license
-can be found in the LICENSE file included with this module.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
