@@ -1,11 +1,12 @@
 package Fey::Meta::Class::Schema;
+BEGIN {
+  $Fey::Meta::Class::Schema::VERSION = '0.33';
+}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.32';
-
 use Fey::DBIManager;
 use Fey::Exceptions qw( param_error );
 
@@ -85,12 +86,20 @@ __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: A metaclass for schema classes
+
+
+
+=pod
 
 =head1 NAME
 
 Fey::Meta::Class::Schema - A metaclass for schema classes
 
+=head1 VERSION
+
+version 0.33
+
 =head1 SYNOPSIS
 
   package MyApp::Schema;
@@ -125,18 +134,17 @@ Returns the L<Fey::Schema> for the metaclass's class.
 
 =head1 AUTHOR
 
-Dave Rolsky, <autarch@urth.org>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-See L<Fey::ORM> for details.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. The full text of the license
-can be found in the LICENSE file included with this module.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
