@@ -1,11 +1,12 @@
 package Fey::Meta::HasMany;
+BEGIN {
+  $Fey::Meta::HasMany::VERSION = '0.33';
+}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.32';
-
 use Fey::Exceptions qw( param_error );
 use Fey::Object::Iterator::FromSelect;
 use Fey::Object::Iterator::FromSelect::Caching;
@@ -122,12 +123,20 @@ __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: A parent for has-many metaclasses
+
+
+
+=pod
 
 =head1 NAME
 
 Fey::Meta::HasMany - A parent for has-many metaclasses
 
+=head1 VERSION
+
+version 0.33
+
 =head1 DESCRIPTION
 
 This class exists to provide a common parent for the two has-many
@@ -201,18 +210,17 @@ and unsets the C<associated_class>.
 
 =head1 AUTHOR
 
-Dave Rolsky, <autarch@urth.org>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-See L<Fey::ORM> for details.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. The full text of the license
-can be found in the LICENSE file included with this module.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
