@@ -1,11 +1,12 @@
 package Fey::Meta::HasMany::ViaSelect;
+BEGIN {
+  $Fey::Meta::HasMany::ViaSelect::VERSION = '0.33';
+}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.32';
-
 use Moose;
 use MooseX::StrictConstructor;
 
@@ -35,12 +36,20 @@ __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: A parent for has-one metaclasses based on a query object
+
+
+
+=pod
 
 =head1 NAME
 
 Fey::Meta::HasMany::ViaSelect - A parent for has-one metaclasses based on a query object
 
+=head1 VERSION
+
+version 0.33
+
 =head1 DESCRIPTION
 
 This class implements a has-one relationship for a class, based on a
@@ -84,18 +93,17 @@ Corresponds to the value passed to the constructor.
 
 =head1 AUTHOR
 
-Dave Rolsky, <autarch@urth.org>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-See L<Fey::ORM> for details.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. The full text of the license
-can be found in the LICENSE file included with this module.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
