@@ -1,11 +1,12 @@
 package Fey::Meta::Method::Constructor;
+BEGIN {
+  $Fey::Meta::Method::Constructor::VERSION = '0.33';
+}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.32';
-
 use Moose;
 
 extends 'Moose::Meta::Method::Constructor';
@@ -136,3 +137,28 @@ sub _inline_write_to_cache {
 
 1;
 
+
+__END__
+=pod
+
+=head1 NAME
+
+Fey::Meta::Method::Constructor
+
+=head1 VERSION
+
+version 0.33
+
+=head1 AUTHOR
+
+  Dave Rolsky <autarch@urth.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Dave Rolsky.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
