@@ -1,20 +1,28 @@
 package Fey::ORM;
+BEGIN {
+  $Fey::ORM::VERSION = '0.33';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '0.32';
-
 use Moose 0.98 ();
 
-
 1;
 
-__END__
+# ABSTRACT: A Fey-based ORM (If you like SQL, you might like Fey::ORM)
+
+
+
+=pod
 
 =head1 NAME
 
-Fey::ORM - A Fey-based ORM
+Fey::ORM - A Fey-based ORM (If you like SQL, you might like Fey::ORM)
+
+=head1 VERSION
+
+version 0.33
 
 =head1 SYNOPSIS
 
@@ -90,10 +98,6 @@ You should start by reading L<Fey::ORM::Manual::Intro>. This will walk
 you through creating a set of classes based on a schema. Then look at
 L<Fey::ORM::Manual> for a list of additional documentation.
 
-=head1 AUTHOR
-
-Dave Rolsky, <autarch@urth.org>
-
 =head1 BUGS
 
 Please report any bugs or feature requests to
@@ -101,12 +105,19 @@ C<bug-fey-orm@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
+  Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. The full text of the license
-can be found in the LICENSE file included with this module.
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Dave Rolsky.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
