@@ -1,10 +1,11 @@
 package Fey::ORM::Policy;
+BEGIN {
+  $Fey::ORM::Policy::VERSION = '0.33';
+}
 
 use strict;
 use warnings;
 
-our $VERSION = '0.32';
-
 use Fey::Object::Policy;
 
 {
@@ -74,12 +75,20 @@ sub has_many_namer (&) {
 
 1;
 
-__END__
+# ABSTRACT: Declarative policies for Fey::ORM using classes
+
+
+
+=pod
 
 =head1 NAME
 
 Fey::ORM::Policy - Declarative policies for Fey::ORM using classes
 
+=head1 VERSION
+
+version 0.33
+
 =head1 SYNOPSIS
 
   package MyApp::Policy;
@@ -194,19 +203,18 @@ from a policy class name.
 
 =head1 AUTHOR
 
-Dave Rolsky, <autarch@urth.org>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-See L<Fey::ORM> for details.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. The full text of the license
-can be found in the LICENSE file included with this module.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
+
