@@ -1,11 +1,12 @@
 package Fey::ORM::Role::Iterator;
+BEGIN {
+  $Fey::ORM::Role::Iterator::VERSION = '0.33';
+}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.32';
-
 use List::AllUtils qw( pairwise );
 use Moose::Role;
 use Moose::Util::TypeConstraints;
@@ -113,12 +114,20 @@ sub remaining_as_hashes {
 
 1;
 
-__END__
+# ABSTRACT: A role for things that iterate over Fey::Object::Table objects
+
+
+
+=pod
 
 =head1 NAME
 
 Fey::ORM::Role::Iterator - A role for things that iterate over Fey::Object::Table objects
 
+=head1 VERSION
+
+version 0.33
+
 =head1 SYNOPSIS
 
   package My::Iterator;
@@ -171,18 +180,17 @@ in L<Fey::Object::Iterator::FromSelect>.
 
 =head1 AUTHOR
 
-Dave Rolsky, <autarch@urth.org>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-See L<Fey::ORM> for details.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. The full text of the license
-can be found in the LICENSE file included with this module.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
