@@ -1,11 +1,12 @@
 package Fey::ORM::Schema;
+BEGIN {
+  $Fey::ORM::Schema::VERSION = '0.33';
+}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.32';
-
 use Fey::Meta::Class::Schema;
 use Fey::Object::Schema;
 
@@ -39,12 +40,20 @@ sub has_schema {
 
 1;
 
-__END__
+# ABSTRACT: Provides sugar for schema-based classes
+
+
+
+=pod
 
 =head1 NAME
 
 Fey::ORM::Schema - Provides sugar for schema-based classes
 
+=head1 VERSION
+
+version 0.33
+
 =head1 SYNOPSIS
 
   package MyApp::Schema;
@@ -72,18 +81,17 @@ the calling class.
 
 =head1 AUTHOR
 
-Dave Rolsky, <autarch@urth.org>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-See L<Fey::ORM> for details.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. The full text of the license
-can be found in the LICENSE file included with this module.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
