@@ -1,11 +1,12 @@
 package Fey::Object::Iterator::FromSelect;
+BEGIN {
+  $Fey::Object::Iterator::FromSelect::VERSION = '0.33';
+}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.32';
-
 use Fey::Exceptions qw( param_error );
 
 use Devel::GlobalDestruction;
@@ -212,29 +213,35 @@ __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: Wraps a DBI statement handle to construct objects from the results
+
+
+
+=pod
 
 =head1 NAME
 
 Fey::Object::Iterator::FromSelect - Wraps a DBI statement handle to construct objects from the results
 
+=head1 VERSION
+
+version 0.33
+
 =head1 SYNOPSIS
 
   use Fey::Object::Iterator::FromSelect;
 
-  my $iter =
-      Fey::Object::Iterator::FromSelect->new
-          ( classes     => 'MyApp::User',
-            select      => $select,
-            dbh         => $dbh,
-            bind_params => \@bind,
-          );
+  my $iter = Fey::Object::Iterator::FromSelect->new(
+      classes     => 'MyApp::User',
+      select      => $select,
+      dbh         => $dbh,
+      bind_params => \@bind,
+  );
 
-  print $iter->index(); # 0
+  print $iter->index();    # 0
 
-  while ( my $user = $iter->next() )
-  {
-      print $iter->index(); # 1, 2, 3, ...
+  while ( my $user = $iter->next() ) {
+      print $iter->index();    # 1, 2, 3, ...
       print $user->username();
   }
 
@@ -457,18 +464,17 @@ This class does the L<Fey::ORM::Role::Iterator> role.
 
 =head1 AUTHOR
 
-Dave Rolsky, <autarch@urth.org>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-See L<Fey::ORM> for details.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. The full text of the license
-can be found in the LICENSE file included with this module.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
