@@ -1,11 +1,12 @@
 package Fey::Object::Policy;
+BEGIN {
+  $Fey::Object::Policy::VERSION = '0.33';
+}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.32';
-
 use List::Util qw( first );
 use Moose;
 use MooseX::StrictConstructor;
@@ -52,12 +53,20 @@ __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: An object representing a specific policy
+
+
+
+=pod
 
 =head1 NAME
 
 Fey::Object::Policy - An object representing a specific policy
 
+=head1 VERSION
+
+version 0.33
+
 =head1 DESCRIPTION
 
 This class provides the non-sugar half of L<Fey::ORM::Policy>. It's
@@ -103,18 +112,17 @@ Sets the naming sub for C<has_many()> methods.
 
 =head1 AUTHOR
 
-Dave Rolsky, <autarch@urth.org>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-See L<Fey::ORM> for details.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. The full text of the license
-can be found in the LICENSE file included with this module.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
