@@ -1,11 +1,12 @@
 package Fey::Object::Table;
+BEGIN {
+  $Fey::Object::Table::VERSION = '0.33';
+}
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.32';
-
 use Fey::Literal::Function;
 use Fey::Placeholder;
 use Fey::SQL;
@@ -459,10 +460,8 @@ sub _set_column_values_from_hashref {
 
     for my $col ( keys %{$values} ) {
         my $set = q{_set_} . $col;
-        my $has = q{has_} . $col;
 
-        $self->$set( $values->{$col} )
-            unless $self->$has();
+        $self->$set( $values->{$col} );
     }
 }
 
@@ -515,15 +514,7 @@ sub _SelectSQLForKey {
 
     my $table = $class->Table();
 
-    my %key = map { $_->name() => 1 } @{$key};
-
-    my @non_key
-        = grep { !$key{ $_->name() } } $table->columns();
-
-    # This is a bit of a hack for tables that consist just of a key
-    # (like a UserGroup table with a user_id and group_id). We need to
-    # select _something_ or else shit blows up.
-    my @select = @non_key ? @non_key : @{$key};
+    my @select = $table->columns();
 
     $select = $class->SchemaClass()->SQLFactoryClass()->new_select();
     $select->select( sort { $a->name() cmp $b->name() } @select );
@@ -563,12 +554,20 @@ __PACKAGE__->meta()->make_immutable( inline_constructor => 0 );
 
 1;
 
-__END__
+# ABSTRACT: Base class for table-based objects
+
+
+
+=pod
 
 =head1 NAME
 
 Fey::Object::Table - Base class for table-based objects
 
+=head1 VERSION
+
+version 0.33
+
 =head1 SYNOPSIS
 
   package MyApp::User;
@@ -779,18 +778,17 @@ by the C<SELECT>.
 
 =head1 AUTHOR
 
-Dave Rolsky, <autarch@urth.org>
+  Dave Rolsky <autarch@urth.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-See L<Fey::ORM> for details.
+This software is copyright (c) 2010 by Dave Rolsky.
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. The full text of the license
-can be found in the LICENSE file included with this module.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
